import { IPackageStorage, IPluginStorage, LocalStorage, Logger, Config, Callback } from '@verdaccio/types';
/**
 * Handle local database.
 */
declare class LocalDatabase implements IPluginStorage<{}> {
    path: string;
    logger: Logger;
    data: LocalStorage;
    config: Config;
    locked: boolean;
    /**
     * Load an parse the local json database.
     * @param {*} path the database path
     */
    constructor(config: Config, logger: Logger);
    getSecret(): Promise<any>;
    setSecret(secret: string): Promise<any>;
    /**
     * Add a new element.
     * @param {*} name
     * @return {Error|*}
     */
    add(name: string, cb: Callback): void;
    search(onPackage: Callback, onEnd: Callback, validateName: any): void;
    _getTime(time: number, mtime: Date): number | Date;
    _getCustomPackageLocalStorages(): {};
    /**
     * Remove an element from the database.
     * @param {*} name
     * @return {Error|*}
     */
    remove(name: string, cb: Callback): void;
    /**
     * Return all database elements.
     * @return {Array}
     */
    get(cb: Callback): void;
    /**
     * Syncronize {create} database whether does not exist.
     * @return {Error|*}
     */
    _sync(): any;
    getPackageStorage(packageName: string): IPackageStorage;
    /**
     * Verify the right local storage location.
     * @param {String} path
     * @return {String}
     * @private
     */
    _getLocalStoragePath(storage: string | void): string;
    /**
     * Build the local database path.
     * @param {Object} config
     * @return {string|String|*}
     * @private
     */
    _buildStoragePath(config: Config): string;
    /**
     * Fetch local packages.
     * @private
     * @return {Object}
     */
    _fetchLocalPackages(): LocalStorage;
}
export default LocalDatabase;
