import { HttpError } from 'http-errors';
import { ReadTarball } from '@verdaccio/streams';
import { Callback, Logger, Package, ILocalPackageManager, CallbackError, IUploadTarball } from '@verdaccio/types';
export declare const fileExist: string;
export declare const noSuchFile: string;
export declare const resourceNotAvailable: string;
export declare const pkgFileName = "package.json";
export declare const fSError: (message: string, code?: number) => HttpError;
export declare const ErrorCode: {
    get503: () => HttpError;
    get404: () => HttpError;
};
export default class LocalFS implements ILocalPackageManager {
    path: string;
    logger: Logger;
    constructor(path: string, logger: Logger);
    /**
      *  This function allows to update the package thread-safely
        Algorithm:
        1. lock package.json for writing
        2. read package.json
        3. updateFn(pkg, cb), and wait for cb
        4. write package.json.tmp
        5. move package.json.tmp package.json
        6. callback(err?)
      * @param {*} name
      * @param {*} updateHandler
      * @param {*} onWrite
      * @param {*} transformPackage
      * @param {*} onEnd
      */
    updatePackage(name: string, updateHandler: Callback, onWrite: Callback, transformPackage: Function, onEnd: Callback): void;
    deletePackage(fileName: string, callback: CallbackError): void;
    removePackage(callback: CallbackError): void;
    createPackage(name: string, value: Package, cb: Function): void;
    savePackage(name: string, value: Package, cb: Function): void;
    readPackage(name: string, cb: Function): void;
    writeTarball(name: string): IUploadTarball;
    readTarball(name: string): ReadTarball;
    _createFile(name: string, contents: any, callback: Function): void;
    _readStorageFile(name: string): Promise<any>;
    _convertToString(value: Package): string;
    _getStorage(fileName?: string): string;
    _writeFile(dest: string, data: string, cb: Function): void;
    _lockAndReadJSON(name: string, cb: Function): void;
    _unlockJSON(name: string, cb: Function): void;
}
